# apeer-ometiff-library

Easily read and write ome-tiff images

The omexmlClass.py file in this library is taken from python-bioformats. We included this part in this library, because it allows us to use these functions without needing to have a Java-VM in Apeer docker files.
